"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.enhanceInitialState = exports.getInitialState = void 0;
// @ts-ignore
const max_1 = require("@umijs/max");
const base_1 = require("@teams-max/base");
const api_1 = require("../../services/api");
const utils_1 = require("../../utils");
const auth_1 = require("../../utils/auth");
const Authorized_1 = require("../../utils/Authorized");
const loginPath = '/user/login';
const { isDEV } = (0, base_1.runtimeConfig)();
/**
 * @see  https://umijs.org/zh-CN/plugins/plugin-initial-state
 * */
async function getInitialState(initialValues) {
    console.log('initialState');
    const { authSuccess } = initialValues || {};
    const fetchUserInfo = async () => {
        try {
            const [userInfo = {}, authority = {}] = await Promise.all([
                (0, api_1.getUserInfo)(),
                (0, api_1.getAuthorityQuery)(),
            ]);
            // 鉴权成功回调
            if (userInfo.code === 0 && authority.code === 0) {
                const { domainAccount = '', accountName = '' } = userInfo.data || {};
                (0, utils_1.initSecurity)(domainAccount, accountName);
                const authorityData = authority.data || [];
                // 初始化权限
                if (Array.isArray(authorityData)) {
                    const currentAuthority = authorityData.map((item) => item.permitCode || item.component);
                    (0, Authorized_1.setAuthority)(currentAuthority, authorityData, max_1.history);
                }
                const token = (0, auth_1.getAccessToken)();
                (0, auth_1.setUserProfile)(userInfo.data || {}); //设置用户信息
                authSuccess === null || authSuccess === void 0 ? void 0 : authSuccess({ userInfo: userInfo.data || {}, authority: authorityData, token });
                return {
                    userInfo: userInfo.data || {},
                    authority: authorityData,
                    token,
                };
            }
            if (userInfo.code !== 0 && authority.code !== 0 && userInfo.code !== 20001) {
                return {
                    exception: authority
                };
            }
        }
        catch (error) {
            console.log('error', error);
        }
        return undefined;
    };
    /**
     * fake登录
     */
    const isFake = !!(0, utils_1.getQueryString)('fake_login') && isDEV;
    if (isFake) {
        return {
            fetchUserInfo,
            settings: {},
            fakeLogin: true,
        };
    }
    //login路由直接退出登录
    if (max_1.history.location.pathname === loginPath) {
        return {
            fetchUserInfo,
            settings: {},
        };
    }
    /**
     * 嵌入登录 优先级 P0
     */
    const appSecret = (0, utils_1.getQueryString)('app_secret');
    if (appSecret && appSecret.length > 10) {
        (0, utils_1.urlReset)('app_secret'); // 清除 浏览器参数
        const res = await (0, auth_1.genAccessToken)(appSecret);
        if (res && typeof res === 'string') {
            (0, auth_1.setAccessToken)(res);
            const currentUser = await fetchUserInfo();
            return {
                ...(currentUser ? currentUser : {}),
                fetchUserInfo,
                settings: {},
            };
        }
        // 已登录用户
        if ((0, auth_1.getAccessToken)()) {
            const currentUser = await fetchUserInfo();
            return {
                ...(currentUser ? currentUser : {}),
                fetchUserInfo,
                settings: {},
            };
        }
        return {
            fetchUserInfo,
            settings: {},
            exception: res
        };
    }
    /**
     * 嵌入登录 待废弃
     * 存在安全风险 不建议使用
     */
    const app_access_token = (0, utils_1.getQueryString)('app_access_token');
    if (app_access_token && app_access_token.length > 10) {
        // 清除 浏览器参数
        (0, utils_1.urlReset)('app_access_token');
        (0, auth_1.setAccessToken)(app_access_token);
        const currentUser = await fetchUserInfo();
        return {
            ...(currentUser ? currentUser : {}),
            fetchUserInfo,
            settings: {},
        };
    }
    /**
     * SSO登录
     */
    const ticket = (0, utils_1.getQueryString)('ticket');
    if (ticket) {
        // 清除 浏览器参数
        (0, utils_1.urlReset)('ticket');
        // SSO 登录
        const res = await (0, api_1.login)({
            ticket,
        });
        const { code, data = {} } = res;
        if (code === 0) {
            // 获取用户 TOKEN 并设置
            const { token } = data;
            (0, auth_1.setAccessToken)(token);
            const currentUser = await fetchUserInfo();
            return {
                ...(currentUser ? currentUser : {}),
                fetchUserInfo,
                settings: {},
            };
        }
        return {
            fetchUserInfo,
            settings: {},
            exception: res
        };
    }
    /**
     * 已登录用户
     */
    if ((0, auth_1.getAccessToken)()) {
        const currentUser = await fetchUserInfo();
        return {
            ...(currentUser ? currentUser : {}),
            fetchUserInfo,
            settings: {},
        };
    }
    return {
        fetchUserInfo,
        settings: {},
    };
}
exports.getInitialState = getInitialState;
function enhanceInitialState({ options }) {
    return async () => {
        return await getInitialState(options);
    };
}
exports.enhanceInitialState = enhanceInitialState;
