"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.enhanceRequest = exports.request = exports.formatStatus = void 0;
const base_1 = require("@teams-max/base");
const antd_1 = require("antd");
// @ts-ignore
const max_1 = require("@umijs/max");
const auth_1 = require("../../utils/auth");
const { confirm } = antd_1.Modal;
const lodash_1 = __importDefault(require("lodash"));
const { baseUrl, AppKey } = (0, base_1.runtimeConfig)();
const codeMessage = {
    200: '服务器成功返回请求的数据',
    201: '新建或修改数据成功',
    202: '一个请求已经进入后台排队（异步任务）',
    204: '删除数据成功',
    400: '抱歉，页面无法访问',
    401: '系统暂时无法获取到您的账号信息',
    403: '抱歉，系统暂时未得到您的授权信息',
    404: '抱歉，您访发出的请求不存在',
    405: '请求方法不被允许',
    406: '请求的格式不可得',
    408: '链接到服务器发生异常，请稍后重试',
    410: '请求的资源被永久删除，且不会再得到的',
    422: '当创建一个对象时，发生一个验证错误',
    500: '服务器发生错误，请检查服务器',
    502: '链接到服务器发生错误，请检查网络',
    503: '服务不可用，服务器暂时过载或维护',
    504: '链接超时，请检查网络',
    9999: '您的网络发生异常，请检查网络',
};
const routerGo = (code) => {
    max_1.history.push({
        pathname: `/exception/${code}`,
    });
};
const errorRes = (code, msg) => {
    return {
        code,
        msg,
        errorMsg: formatStatus(code),
        success: false,
    };
};
function formatStatus(status) {
    return codeMessage[status] || `抱歉，访问失败请稍后重试。`;
}
exports.formatStatus = formatStatus;
/**
 * 节流 Tips
 * @param msg 提示信息
 * @param type 提示类型
 */
const errorTips = lodash_1.default.throttle((msg, status = 9999, type) => {
    if ([10201, 10301, 20001].includes(status))
        return;
    const message = !!msg ? msg : formatStatus(status);
    if (type === 'confirm') {
        confirm({
            title: '提示',
            content: message,
            onOk() {
                routerGo(status);
            },
        });
    }
    else {
        antd_1.message.error({
            content: message,
            duration: 5,
        });
    }
}, 1000);
// /** 异常处理程序 */
const errorHandler = (error) => {
    const { response } = error;
    if (response && response.status) {
        const errorText = codeMessage[response.status] || response.statusText;
        const { status } = response;
        errorTips(errorText, status, 'tips');
        return errorRes(status);
    }
    // response 数据结构异常
    errorTips('您的网络发生异常，无法连接服务器', 9999, 'tips');
    return errorRes(999999);
};
const requestInterceptor = (options) => {
    const nextOptions = { ...options };
    nextOptions.headers.AppKey = AppKey;
    const isFormData = options.data && Object.getPrototypeOf(options.data) === FormData.prototype;
    if (!isFormData) {
        nextOptions.headers['Content-Type'] = 'application/json';
    }
    const keys = Object.keys(nextOptions.headers);
    if (!keys.includes('useErrorTips')) {
        nextOptions.headers.useErrorTips = true;
    }
    /* eslint-disable no-underscore-dangle */
    const accessToken = (0, auth_1.getAccessToken)();
    if (accessToken) {
        nextOptions.headers.Authorization = accessToken;
    }
    return {
        ...nextOptions,
    };
};
const responseInterceptor = async (response) => {
    const { status, headers = {}, config = {}, data = {} } = response;
    const { useErrorTips } = config.headers;
    if (status !== 200) {
        return errorRes(status);
    }
    const contentType = headers['content-type'] || '';
    if (!contentType.includes('application/json')) {
        return response;
    }
    const { message, msg, errorMsg, success } = data;
    let { code } = data;
    if (success) {
        code = 0;
    }
    const errMsg = message || msg || errorMsg;
    if (Number(code) !== 0) {
        if ([-115, 401, 403].includes(code)) {
            routerGo(code);
            return response;
        }
        if ([10201, 10301].includes(code)) {
            (0, auth_1.userLogOut)();
            return response;
        }
        if (useErrorTips) {
            errorTips(errMsg, code, 'tips');
        }
    }
    return response;
};
// 运行时配置 https://umijs.org/zh-CN/plugins/plugin-request#userequest
exports.request = {
    baseURL: baseUrl,
    timeout: 10000,
    errorConfig: {
        errorHandler,
    },
    requestInterceptors: [requestInterceptor],
    responseInterceptors: [responseInterceptor],
};
//注意： 我们会按照你的数组顺序依次注册拦截器，但是其执行顺序参考 axios，request 是后添加的在前，response 是后添加的在后
const enhanceRequest = ({ options, covered }) => {
    if (!options) {
        return exports.request;
    }
    if (covered) {
        return options;
    }
    const { requestInterceptors = [], responseInterceptors = [] } = options;
    return {
        ...exports.request,
        ...options,
        requestInterceptors: [...(exports.request.requestInterceptors || []), ...requestInterceptors],
        responseInterceptors: [...(exports.request.responseInterceptors || []), ...responseInterceptors],
    };
};
exports.enhanceRequest = enhanceRequest;
