"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.openMchUrl = exports.userLogOut = exports.getErrorInfo = exports.setErrorInfo = exports.clearAccessToken = exports.genAccessToken = exports.genShorten = exports.getUserProfile = exports.setUserProfile = exports.setAccessToken = exports.getAccessToken = void 0;
const qs_1 = require("qs");
const base_1 = require("@teams-max/base");
const api_1 = require("../services/api");
const index_1 = require("./index");
// @ts-ignore
const max_1 = require("@umijs/max");
const { sessionNameId, logoutUrl, platform, MAX_APP_ENV, isIntranet } = (0, base_1.runtimeConfig)();
/**
 * 获取用户 TOKEN
 * @return  {string}  处理过的用户 TOKEN
 */
function getAccessToken() {
    if (window[sessionNameId]) {
        return window[sessionNameId];
    }
    const accessToken = localStorage.getItem(sessionNameId);
    window[sessionNameId] = accessToken;
    return accessToken;
}
exports.getAccessToken = getAccessToken;
/**
 * 设置用户 TOKEN
 * @return  {string}  处理过的用户 TOKEN
 */
function setAccessToken(accessToken) {
    window[sessionNameId] = accessToken;
    localStorage.setItem(sessionNameId, accessToken);
    return accessToken;
}
exports.setAccessToken = setAccessToken;
/**
 * 设置用户信息
 * @return  {string}  处理过的用户 TOKEN
 */
function setUserProfile(userInfo = {}) {
    window[`${sessionNameId}_USER_PROFILE`] = userInfo;
    localStorage.setItem(`${sessionNameId}_USER_PROFILE`, encodeURIComponent(JSON.stringify(userInfo)));
    return window[`${sessionNameId}_USER_PROFILE`];
}
exports.setUserProfile = setUserProfile;
/**
 * 获取用户信息
 * @return  {string}  处理过的用户 TOKEN
 */
function getUserProfile() {
    if (window[`${sessionNameId}_USER_PROFILE`]) {
        return window[`${sessionNameId}_USER_PROFILE`];
    }
    let userinfo;
    const userInfoStr = localStorage.getItem(`${sessionNameId}_USER_PROFILE`) || '';
    try {
        userinfo = JSON.parse(decodeURIComponent(userInfoStr)) || {};
    }
    catch (e) {
        userinfo = {};
    }
    return userinfo;
}
exports.getUserProfile = getUserProfile;
/**
 * TOKEN 转 短Key
 * @return  {string}  处理过的 短Key
 */
async function genShorten(url, antoJump = true) {
    const res = await (0, api_1.fetchGenShorten)();
    if (res.code !== 0 || !res.data)
        return;
    const appSecret = res.data;
    if (url && (0, index_1.isUrl)(url)) {
        const loactionPath = url.replace('?=', '?').split('?')[0];
        const query = (0, index_1.getPageQuery)(url);
        query['app_secret'] = appSecret;
        const nextURL = `${loactionPath}?${(0, index_1.jsonToString)(query)}`;
        if (antoJump) {
            // window.location.href = nextURL;
            window.location.replace(nextURL);
            return;
        }
        return {
            secret: appSecret,
            url: nextURL,
        };
    }
    return appSecret;
}
exports.genShorten = genShorten;
/**
 * 短Key 转 TOKEN
 * @return  {string}  处理过的用户 TOKEN
 */
async function genAccessToken(encrypt) {
    if (!encrypt)
        return;
    const res = await (0, api_1.fetchShorten)({
        encrypt,
    });
    const { token } = res.data || {};
    if (res.code !== 0 || !token) {
        return res;
    }
    return token;
}
exports.genAccessToken = genAccessToken;
/**
 * 清除用户 TOKEN
 * @return  {undefined}  undefined
 */
function clearAccessToken() {
    localStorage.removeItem(sessionNameId);
    window[sessionNameId] = undefined;
    return undefined;
}
exports.clearAccessToken = clearAccessToken;
/**
 * 设置错误信息
 */
function setErrorInfo(code, value = {}) {
    sessionStorage.setItem(`__express${code}`, JSON.stringify(value));
}
exports.setErrorInfo = setErrorInfo;
/**
 * 获取错误信息
 * @return  {string}  处理过的错误信息
 */
function getErrorInfo(code) {
    if (!code)
        return undefined;
    return JSON.parse(sessionStorage.getItem(`__express${code}`) || '{}');
}
exports.getErrorInfo = getErrorInfo;
/**
 * 用户退出
 */
async function userLogOut(type) {
    const token = getAccessToken();
    if (token && !platform.isTeams) {
        await (0, api_1.logOut)(token);
    }
    clearAccessToken();
    if (type === 'fake_login') {
        const query = (0, index_1.getPageQuery)();
        delete query.fake_login;
        const search = {
            fake_login: true,
            redirect: `${window.location.origin}${window.location.pathname}${(0, index_1.getQueryStr)(query)}`,
        };
        max_1.history.replace({
            pathname: 'user/login',
            search: (0, qs_1.stringify)(search)
        });
        return;
    }
    // Note: There may be security issues, please note
    if (window.location.pathname.includes('login'))
        return;
    if (type === 'mobileNum') {
        max_1.history.replace({
            pathname: 'user/login',
            search: (0, qs_1.stringify)({ redirect: window.location.href })
        });
        return;
    }
    //内网退出到sso登录
    if (isIntranet && !platform.isTeams) {
        location.href = logoutUrl; // 无登录用户跳出
        return;
    }
    const query = (0, index_1.getPageQuery)();
    delete query.redirect;
    const search = {
        redirect: `${window.location.origin}${window.location.pathname}${(0, index_1.getQueryStr)(query)}`,
    };
    max_1.history.replace({
        pathname: '/exception/401',
        search: (0, qs_1.stringify)(search)
    });
}
exports.userLogOut = userLogOut;
/**
 * 第三方应用登录
 * @param { * 第三方登录链接 } mchUrl
 * @param { * 登录成功后的回调方法 } callback fn | url
 */
async function openMchUrl(mchUrl, callback) {
    const res = await (0, api_1.mchAuthLogin)(mchUrl);
    if (res.code !== 0)
        return;
    const { redirectUrl } = res.data || {};
    if (!redirectUrl) {
        if (callback && typeof callback === 'function')
            callback(res);
        return;
    }
    const mchFrameId = `___g__mch_auth_frame_${+new Date()}`;
    const docIframe = document.createElement('iframe');
    docIframe.src = redirectUrl;
    docIframe.style =
        'position: absolute; left: -9999px; top: -9999px; z-index: -9999; width: 10px; height: 10px;';
    docIframe.id = mchFrameId;
    document.body.appendChild(docIframe);
    const frameReadyFn = () => {
        const el = document.body.querySelector(`#${mchFrameId}`);
        if (el) {
            document.body.removeChild(el);
        }
        if (callback && typeof callback === 'string' && (0, index_1.isUrl)(callback)) {
            // window.location.href = callback;
            window.location.replace(callback);
            return;
        }
        if (callback)
            callback(res);
    };
    if (docIframe.attachEvent) {
        docIframe.attachEvent('onload', function () {
            frameReadyFn();
        });
    }
    else {
        docIframe.onload = function () {
            frameReadyFn();
        };
    }
}
exports.openMchUrl = openMchUrl;
